Jido.Messaging.Demo.Messaging (Jido Messaging v1.0.0)

Copy Markdown View Source

Demo messaging instance for the echo bot demo.

Summary

Functions

Returns naming info for this instance

Archive a dead-letter record by ID.

Assign a thread to an agent

Get runtime status for a bridge worker.

Check if a message key is a duplicate (and mark as seen if new)

Clear all dedupe keys

Count running agents

Count running instances

Count running room servers

Create or ensure a bridge-backed room topology in one call.

Create a new participant

Create a new room

Create a binding between an internal room and an external platform

Delete bridge config.

Delete adapter-scoped provider ingress subscription for a bridge.

Delete a message

Delete a room

Delete a room binding

Delete routing policy for room.

Lookup a single directory entry.

Ensure adapter-scoped provider ingress subscription for a bridge.

Fetch bridge config by id.

Get a dead-letter record by ID.

Get a message by ID

Get a message by its external ID within a channel/bridge context

Fetch onboarding flow state.

Get or start a room server

Get a participant by ID

Get a room by ID

Get room by external binding (without creating)

Fetch routing policy for room.

Get a thread by ID

Get a thread by external thread ID within a room

Get health snapshot for an instance

Get instance status

List registered agents in a room

List bridge configs.

List runtime status for all bridge workers.

List running bridge workers

List dead-letter records.

List adapter-scoped provider ingress subscriptions for a bridge.

Get health snapshots for all running instances

List all running instances

List messages for a room

List all bindings for a room

List all running room servers

List rooms with optional filters

List threads in a room

Purge dead-letter records by filter.

Create or update bridge config.

Create or update per-room routing policy.

Register an agent with a room

Replay a dead-letter record by ID.

Resolve configured outbound adapter routes for a room.

Resume an onboarding flow.

Route outbound text through bridge bindings/policy for a room.

Route direct payload through bridge-config transform path into ingest.

Route webhook payload through bridge-config parse/verify path into ingest.

Route webhook request and return typed webhook response + ingest outcome.

Save a message

Save an already-constructed message struct (for updates)

Save a room struct directly (for custom IDs)

Save a thread

Save an already-constructed thread struct (for updates)

Check if a message key has been seen

Start a new channel instance

Start (or resume) an onboarding flow.

Start a room server for the given room

Stop an instance

Stop a room server

Subscribe to room events via PubSub

Fetch thread assignment

Unregister an agent from a room

Unsubscribe from room events

Find a running agent by room, thread, and agent ID

Find the onboarding worker PID for a flow.

Find a running room server by room ID

Functions

__jido_messaging__(key)

Returns naming info for this instance

advance_onboarding(onboarding_id, transition, metadata \\ %{}, opts \\ [])

Advance an onboarding flow.

archive_dead_letter(dead_letter_id)

Archive a dead-letter record by ID.

assign_thread(room_id, thread_id, agent_id)

Assign a thread to an agent

bridge_status(bridge_id)

Get runtime status for a bridge worker.

cancel_onboarding(onboarding_id, metadata \\ %{}, opts \\ [])

Cancel an onboarding flow.

check_dedupe(key, ttl_ms \\ nil)

Check if a message key is a duplicate (and mark as seen if new)

child_spec(init_opts)

clear_dedupe()

Clear all dedupe keys

complete_onboarding(onboarding_id, metadata \\ %{}, opts \\ [])

Complete an onboarding flow.

count_agents()

Count running agents

count_instances()

Count running instances

count_room_servers()

Count running room servers

create_bridge_room(attrs)

Create or ensure a bridge-backed room topology in one call.

create_participant(attrs)

Create a new participant

create_room(attrs)

Create a new room

create_room_binding(room_id, channel, bridge_id, external_id, attrs \\ %{})

Create a binding between an internal room and an external platform

delete_bridge_config(bridge_id)

Delete bridge config.

delete_ingress_subscription(bridge_id, subscription_id, opts \\ [])

Delete adapter-scoped provider ingress subscription for a bridge.

delete_message(message_id)

Delete a message

delete_room(room_id)

Delete a room

delete_room_binding(binding_id)

Delete a room binding

delete_routing_policy(room_id)

Delete routing policy for room.

directory_lookup(target, query, opts \\ [])

Lookup a single directory entry.

directory_search(target, query, opts \\ [])

Search directory entries.

ensure_ingress_subscription(bridge_id, opts \\ [])

Ensure adapter-scoped provider ingress subscription for a bridge.

get_bridge_config(bridge_id)

Fetch bridge config by id.

get_dead_letter(dead_letter_id)

Get a dead-letter record by ID.

get_message(message_id)

Get a message by ID

get_message_by_external_id(channel, bridge_id, external_id)

Get a message by its external ID within a channel/bridge context

get_onboarding(onboarding_id)

Fetch onboarding flow state.

get_or_create_participant_by_external_id(channel, external_id, attrs \\ %{})

Get or create participant by external ID

get_or_create_room_by_external_binding(channel, bridge_id, external_id, attrs \\ %{})

Get or create room by external binding

get_or_start_room_server(room, opts \\ [])

Get or start a room server

get_participant(participant_id)

Get a participant by ID

get_room(room_id)

Get a room by ID

get_room_by_external_binding(channel, bridge_id, external_id)

Get room by external binding (without creating)

get_routing_policy(room_id)

Fetch routing policy for room.

get_thread(thread_id)

Get a thread by ID

get_thread_by_external_id(room_id, external_thread_id)

Get a thread by external thread ID within a room

get_thread_by_root_message(room_id, root_message_id)

Get a thread by root message ID

instance_health(instance_id)

Get health snapshot for an instance

instance_status(instance_id)

Get instance status

list_agents(room_id)

List registered agents in a room

list_bridge_configs(opts \\ [])

List bridge configs.

list_bridge_status()

List runtime status for all bridge workers.

list_bridges()

List running bridge workers

list_dead_letters(opts \\ [])

List dead-letter records.

list_ingress_subscriptions(bridge_id, opts \\ [])

List adapter-scoped provider ingress subscriptions for a bridge.

list_instance_health()

Get health snapshots for all running instances

list_instances()

List all running instances

list_messages(room_id, opts \\ [])

List messages for a room

list_room_bindings(room_id)

List all bindings for a room

list_room_servers()

List all running room servers

list_rooms(opts \\ [])

List rooms with optional filters

list_threads(room_id, opts \\ [])

List threads in a room

purge_dead_letters(opts \\ [])

Purge dead-letter records by filter.

put_bridge_config(attrs)

Create or update bridge config.

put_routing_policy(room_id, attrs)

Create or update per-room routing policy.

register_agent(room_id, agent_spec, opts \\ [])

Register an agent with a room

replay_dead_letter(dead_letter_id, opts \\ [])

Replay a dead-letter record by ID.

resolve_outbound_routes(room_id, opts \\ [])

Resolve configured outbound adapter routes for a room.

resume_onboarding(onboarding_id)

Resume an onboarding flow.

route_outbound(room_id, text, opts \\ [])

Route outbound text through bridge bindings/policy for a room.

route_payload(bridge_id, payload, opts \\ [])

Route direct payload through bridge-config transform path into ingest.

route_webhook(bridge_id, payload, opts \\ [])

Route webhook payload through bridge-config parse/verify path into ingest.

route_webhook_request(bridge_id, request_meta, payload, opts \\ [])

Route webhook request and return typed webhook response + ingest outcome.

save_message(attrs)

Save a message

save_message_struct(message)

Save an already-constructed message struct (for updates)

save_room(room)

Save a room struct directly (for custom IDs)

save_thread(attrs)

Save a thread

save_thread_struct(thread)

Save an already-constructed thread struct (for updates)

seen?(key)

Check if a message key has been seen

start_instance(channel_type, attrs \\ %{})

Start a new channel instance

start_link(opts \\ [])

start_onboarding(attrs, opts \\ [])

Start (or resume) an onboarding flow.

start_room_server(room, opts \\ [])

Start a room server for the given room

stop_instance(instance_id)

Stop an instance

stop_room_server(room_id)

Stop a room server

subscribe(room_id)

Subscribe to room events via PubSub

thread_assignment(room_id, thread_id)

Fetch thread assignment

unassign_thread(room_id, thread_id)

Unassign a thread

unregister_agent(room_id, agent_id)

Unregister an agent from a room

unsubscribe(room_id)

Unsubscribe from room events

update_message_external_id(message_id, external_id)

Update a message's external_id

whereis_agent(room_id, thread_id, agent_id)

Find a running agent by room, thread, and agent ID

whereis_onboarding_worker(onboarding_id)

Find the onboarding worker PID for a flow.

whereis_room_server(room_id)

Find a running room server by room ID