Dynamic supervisor for onboarding workers partitioned by onboarding ID.
Summary
Functions
Returns a specification to start this module under a supervisor.
Returns the number of active onboarding workers for an instance.
Returns the worker for an onboarding flow, starting it when necessary.
Starts the dynamic supervisor for onboarding workers.
Starts or returns the worker for an onboarding flow.
Resolves the registered supervisor name for an instance module.
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
@spec count_workers(module()) :: non_neg_integer()
Returns the number of active onboarding workers for an instance.
Returns the worker for an onboarding flow, starting it when necessary.
@spec start_link(keyword()) :: Supervisor.on_start()
Starts the dynamic supervisor for onboarding workers.
Starts or returns the worker for an onboarding flow.
Resolves the registered supervisor name for an instance module.