Main supervisor for a Jido.Messaging instance.
Started by the host application's messaging module (defined with use Jido.Messaging).
Each instance has its own isolated supervision tree.
Summary
Functions
Returns a specification to start this module under a supervisor.
Returns the Signal Bus name for a given messaging module.
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
Returns the Signal Bus name for a given messaging module.