DynamicSupervisor for spawning and managing RoomServer processes.
Each Jido.Messaging instance has its own RoomSupervisor that manages room servers on-demand.
Summary
Functions
Returns a specification to start this module under a supervisor.
Count running room servers
Get an existing room server or start a new one.
List all running room servers for this instance
Start a room server for the given room.
Stop a room server.
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
Count running room servers
Get an existing room server or start a new one.
Returns {:ok, pid} in both cases.
List all running room servers for this instance
Start a room server for the given room.
Returns {:ok, pid} if started successfully, or {:error, {:already_started, pid}}
if the room server is already running.
Options:
:message_limit- Max messages to keep in memory (default: 100):timeout_ms- Inactivity timeout (default: 5 minutes)
Stop a room server.
Returns :ok if stopped, or {:error, :not_found} if not running.